/* This is a Cfunctions (version 0.28) generated header file.
   Cfunctions is a free program for extracting headers from C files.
   Get Cfunctions from 'http://www.lemoda.net/cfunctions/'. */

/* This file was generated with:
'cfunctions -inc edit-distance.c' */
#ifndef CFH_EDIT_DISTANCE_H
#define CFH_EDIT_DISTANCE_H

/* From 'edit-distance.c': */

#line 12 "edit-distance.c"
int distance (const char * word1 , int len1 , const char * word2 , int len2 , int max );

#endif /* CFH_EDIT_DISTANCE_H */
